Documentation
¶
Index ¶
- func CatalogCreate(ui UI, catalogNameStr string) error
- func Init(ui UI) error
- func ReleaseAddItem(ui UI, itemNameStr, wareStr string) error
- func ReleaseCommit(ui UI) error
- func ReleaseStart(ui UI, catalogNameStr, releaseNameStr string) error
- func Show(ui UI, nameStr string) error
- type ErrorCategory
- type ReleaseEntryBuilder
- type UI
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CatalogCreate ¶
func ReleaseAddItem ¶
func ReleaseCommit ¶
func ReleaseStart ¶
Types ¶
type ErrorCategory ¶
type ErrorCategory string
const ( ErrBadArgs ErrorCategory = "badargs" // Indicates usage errors. ErrCorruptState ErrorCategory = "corruptstate" // Indicates saved state is corrupt somehow (does not parse, or fails invariant checks). ErrDataNotFound ErrorCategory = "datanotfound" // Indicates content not found -- the db was, but the e.g. catalog name (or release name, etc; whatever was requested) was not present. ErrFS ErrorCategory = "fs" // Indicates some local I/O error: permission denied, etc. Retries unwise. ErrDBNotFound ErrorCategory = "dbnotfound" // Returned when a hitch command is used outside of a hitch.db path. ErrInProgress ErrorCategory = "inprogress" // Indicates desired operation is already begun -- e.g., `hitch init` is used and a hitch.db already exists; `hitch release start` when something is already staged, etc. ErrNameCollision ErrorCategory = "namecollision" // Indicates that a name is already used, e.g. a catalog already has a release of the same name you just tried to create, etc. ErrPiping ErrorCategory = "pipecollapse" // Returned when IO to the *user* (e.g. stdout) fails. (*Not* when disk or db IO fails.) )
type ReleaseEntryBuilder ¶
type ReleaseEntryBuilder struct {
}
func (*ReleaseEntryBuilder) AppendStep ¶
func (x *ReleaseEntryBuilder) AppendStep( name api.StepName, upstream map[api.AbsPath]api.ReleaseItemID, formula api.Formula, runRecord api.RunRecord, )
func (*ReleaseEntryBuilder) MustVerify ¶
func (x *ReleaseEntryBuilder) MustVerify()
Call Verify or MustVerify to check the connectedness of all steps in the entry so far.
Calling this after every append is possible if you know you're streaming in records in the same order they were built, but it's equally valid to append an unordered set of records and then call verify once at the end.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.