stage

package
v0.0.0-...-ff4f71a Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 10, 2018 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Overview

Package 'stage' handles assembling a release.

Making a new release often takes a series of hitch commands -- this matches how making a release often requires *several* large computations -- so all the intermediate staged states are serializable to disk.

Index

Constants

const DefaultPath = "_stage"

Variables

This section is empty.

Functions

func Clear

func Clear(dbctrl *db.Controller, stagePath string) error

Types

type Controller

type Controller struct {
	Catalog api.Catalog // catalog struct, sync'd with file.  always must have exactly one release entry.
	// contains filtered or unexported fields
}

func Create

func Create(
	dbctrl *db.Controller, stagePath string,
	catalogName api.CatalogName, releaseName api.ReleaseName,
) (*Controller, error)

Create a new empty release staging state. Makes a dir, and creates the sigil file.

func Load

func Load(dbctrl *db.Controller, stagePath string) (*Controller, error)

func (*Controller) Save

func (stageCtrl *Controller) Save() error

type ErrorCategory

type ErrorCategory string
const (
	ErrIO             ErrorCategory = "ErrIO"
	ErrStorageCorrupt ErrorCategory = "ErrStorageCorrupt"
)

Jump to